Removed last argument 'secondary' and restructured
i3c_master_register to move code that can be common
to i3c_secondary_master_register to separate function
i3c_master_init.

Signed-off-by: Parshuram Thombare <pthom...@cadence.com>
---
 drivers/i3c/master.c                 | 74 +++++++++++++++++-----------
 drivers/i3c/master/dw-i3c-master.c   |  4 +-
 drivers/i3c/master/i3c-master-cdns.c |  4 +-
 include/linux/i3c/master.h           |  7 ++-
 4 files changed, 51 insertions(+), 38 deletions(-)

diff --git a/drivers/i3c/master/dw-i3c-master.c 
b/drivers/i3c/master/dw-i3c-master.c
index 1d83c97431c7..47d47aa97569 100644
--- a/drivers/i3c/master/dw-i3c-master.c
+++ b/drivers/i3c/master/dw-i3c-master.c
@@ -1157,8 +1157,8 @@ static int dw_i3c_probe(struct platform_device *pdev)
        master->maxdevs = ret >> 16;
        master->free_pos = GENMASK(master->maxdevs - 1, 0);
 
-       ret = i3c_master_register(&master->base, &pdev->dev,
-                                 &dw_mipi_i3c_ops, false);
+       ret = i3c_primary_master_register(&master->base, &pdev->dev,
+                                         &dw_mipi_i3c_ops);
        if (ret)
                goto err_assert_rst;
 
diff --git a/drivers/i3c/master/i3c-master-cdns.c 
b/drivers/i3c/master/i3c-master-cdns.c
index 8889a4fdb454..c7db02543e33 100644
--- a/drivers/i3c/master/i3c-master-cdns.c
+++ b/drivers/i3c/master/i3c-master-cdns.c
@@ -1614,8 +1614,8 @@ static int cdns_i3c_master_probe(struct platform_device 
*pdev)
        writel(MST_INT_IBIR_THR, master->regs + MST_IER);
        writel(DEVS_CTRL_DEV_CLR_ALL, master->regs + DEVS_CTRL);
 
-       ret = i3c_master_register(&master->base, &pdev->dev,
-                                 &cdns_i3c_master_ops, false);
+       ret = i3c_primary_master_register(&master->base, &pdev->dev,
+                                         &cdns_i3c_master_ops);
        if (ret)
                goto err_disable_sysclk;
 
diff --git a/include/linux/i3c/master.h b/include/linux/i3c/master.h
index f13fd8b1dd79..a19d0ad4de8a 100644
--- a/include/linux/i3c/master.h
+++ b/include/linux/i3c/master.h
@@ -531,10 +531,9 @@ int i3c_master_do_daa(struct i3c_master_controller 
*master);
 int i3c_master_set_info(struct i3c_master_controller *master,
                        const struct i3c_device_info *info);
 
-int i3c_master_register(struct i3c_master_controller *master,
-                       struct device *parent,
-                       const struct i3c_master_controller_ops *ops,
-                       bool secondary);
+int i3c_primary_master_register(struct i3c_master_controller *master,
+                               struct device *parent,
+                               const struct i3c_master_controller_ops *ops);
 int i3c_master_unregister(struct i3c_master_controller *master);
 
 /**
diff --git a/drivers/i3c/master.c b/drivers/i3c/master.c
index 5f4bd52121fe..574c3603db38 100644
--- a/drivers/i3c/master.c
+++ b/drivers/i3c/master.c
@@ -1613,7 +1613,7 @@ static void i3c_master_detach_free_devs(struct 
i3c_master_controller *master)
 }
 
 /**
  * i3c_master_bus_init() - initialize an I3C bus
  * @master: main master initializing the bus
  *
  * This function is following all initialisation steps described in the I3C
@@ -1642,7 +1642,7 @@ static void i3c_master_detach_free_devs(struct 
i3c_master_controller *master)
  *
  * Return: a 0 in case of success, an negative error code otherwise.
  */
-static int i3c_master_bus_init(struct i3c_master_controller *master)
+static int i3c_primary_master_bus_init(struct i3c_master_controller *master)
 {
        enum i3c_addr_slot_status status;
        struct i2c_dev_boardinfo *i2cboardinfo;
@@ -2391,31 +2391,10 @@ static int i3c_master_check_ops(const struct 
i3c_master_controller_ops *ops)
        return 0;
 }
 
-/**
- * i3c_master_register() - register an I3C master
- * @master: master used to send frames on the bus
- * @parent: the parent device (the one that provides this I3C master
- *         controller)
- * @ops: the master controller operations
- * @secondary: true if you are registering a secondary master. Will return
- *            -ENOTSUPP if set to true since secondary masters are not yet
- *            supported
- *
- * This function takes care of everything for you:
- *
- * - creates and initializes the I3C bus
- * - populates the bus with static I2C devs if @parent->of_node is not
- *   NULL
- * - registers all I3C devices added by the controller during bus
- *   initialization
- * - registers the I2C adapter and all I2C devices
- *
- * Return: 0 in case of success, a negative error code otherwise.
- */
-int i3c_master_register(struct i3c_master_controller *master,
-                       struct device *parent,
-                       const struct i3c_master_controller_ops *ops,
-                       bool secondary)
+static int i3c_master_init(struct i3c_master_controller *master,
+                          struct device *parent,
+                          const struct i3c_master_controller_ops *ops,
+                          bool secondary)
 {
        struct i3c_bus *i3cbus = i3c_master_get_bus(master);
        enum i3c_bus_mode mode = I3C_BUS_MODE_PURE;
@@ -2478,10 +2457,46 @@ int i3c_master_register(struct i3c_master_controller 
*master,
                goto err_put_dev;
        }
 
-       ret = i3c_master_bus_init(master);
+       ret = i3c_primary_master_bus_init(master);
        if (ret)
                goto err_put_dev;
 
+       return 0;
+
+err_put_dev:
+       put_device(&master->dev);
+
+       return ret;
+}
+
+/**
+ * i3c_primary_master_register() - register an I3C master
+ * @master: master used to send frames on the bus
+ * @parent: the parent device (the one that provides this I3C master
+ *         controller)
+ * @ops: the master controller operations
+ *
+ * This function takes care of everything for you:
+ *
+ * - creates and initializes the I3C bus
+ * - populates the bus with static I2C devs if @parent->of_node is not
+ *   NULL
+ * - registers all I3C devices added by the controller during bus
+ *   initialization
+ * - registers the I2C adapter and all I2C devices
+ *
+ * Return: 0 in case of success, a negative error code otherwise.
+ */
+int i3c_primary_master_register(struct i3c_master_controller *master,
+                               struct device *parent,
+                               const struct i3c_master_controller_ops *ops)
+{
+       int ret;
+
+       ret = i3c_master_init(master, parent, ops, false);
+       if (ret)
+               return ret;
+
        ret = device_add(&master->dev);
        if (ret)
                goto err_cleanup_bus;
@@ -2511,12 +2526,11 @@ int i3c_master_register(struct i3c_master_controller 
*master,
 err_cleanup_bus:
        i3c_master_bus_cleanup(master);
 
-err_put_dev:
        put_device(&master->dev);
 
        return ret;
 }
-EXPORT_SYMBOL_GPL(i3c_master_register);
+EXPORT_SYMBOL_GPL(i3c_primary_master_register);
 
 /**
  * i3c_master_unregister() - unregister an I3C master
@@ -1613,7 +1613,7 @@ static void i3c_master_detach_free_devs(struct 
 
 /**
- * i3c_master_bus_init() - initialize an I3C bus
+ * i3c_primary_master_bus_init() - initialize an I3C bus
  * @master: main master initializing the bus
  *
-- 
2.17.1

Reply via email to